pub struct Version {
pub major: u8,
pub minor: u8,
pub patch: u8,
}Expand description
Represents a version number as used for the bootloader firmware version.
Fields
major: u8The major version, incremented for breaking changes.
minor: u8The minor versions, incremented when features are added in a backwards-compatible manner.
patch: u8The patch version, incremented for backwards-compatible bug fixes.